@@ -27,14 +27,15 @@
 
 // Konsole
 #include "Profile.h"
-#include "ViewContainer.h"
 
 class QSignalMapper;
+class QMenu;
 class KActionCollection;
 class KConfigGroup;
 
 namespace Konsole
 {
+
 class ColorScheme;
 class IncrementalSearchBar;
 class Session;
@@ -42,6 +43,7 @@ class TerminalDisplay;
 
 class SessionController;
 class ViewProperties;
+class ViewContainer;
 class ViewSplitter;
 
 /**
@@ -65,8 +67,8 @@ class ViewSplitter;
  */
 class KONSOLEPRIVATE_EXPORT ViewManager : public QObject
 {
-    Q_OBJECT
-    Q_CLASSINFO("D-Bus Interface", "org.kde.konsole.Window")
+Q_OBJECT
+Q_CLASSINFO("D-Bus Interface", "org.kde.konsole.Konsole")
 
 public:
     /**
@@ -78,7 +80,7 @@ public:
     ~ViewManager();
 
     /**
-     * Creates a new view to display the output from and deliver input to @p session.
+     * Creates a new view to display the outout from and deliver input to @p session.
      * Constructs a new container to hold the views if no container has yet been created.
      */
     void createView(Session* session);
@@ -89,6 +91,12 @@ public:
      */
     void applyProfileToView(TerminalDisplay* view , const Profile::Ptr profile);
 
+    /**
+     * Applies the container-specific settings associated with specified @p
+     * profile to the view container @p container.
+     */
+    void applyProfileToContainer(ViewContainer* container , const Profile::Ptr profile);
+
     /**
      * Return the main widget for the view manager which
      * holds all of the views managed by this ViewManager instance.
@@ -114,7 +122,8 @@ public:
      * which newly created containers can provide to allow navigation
      * between open sessions.
      */
-    enum NavigationMethod {
+    enum NavigationMethod
+    {
         /**
          * Each container has a row of tabs (one per session) which the user
          * can click on to navigate between open sessions.
@@ -124,16 +133,6 @@ public:
         NoNavigation
     };
 
-    /**
-     * This enum describes where newly created tab should be placed.
-     */
-    enum NewTabBehavior {
-        /** Put newly created tab at the end. */
-        PutNewTabAtTheEnd = 0,
-        /** Put newly created tab right after current tab. */
-        PutNewTabAfterCurrentTab = 1
-    };
-
     /**
      * Sets the type of widget provided to navigate between open sessions
      * in a container.  The changes will only apply to newly created containers.
@@ -166,17 +165,6 @@ public:
     void saveSessions(KConfigGroup& group);
     void restoreSessions(const KConfigGroup& group);
 
-    void setNavigationVisibility(int visibility);
-    void setNavigationPosition(int position);
-    void setNavigationBehavior(int behavior);
-    void setNavigationStyleSheet(const QString& styleSheet);
-    void setShowQuickButtons(bool show);
-
-    int managerId() const;
-
-    /** Returns a list of sessions in this ViewManager */
-    QList<Session*> sessions() { return _sessionMap.values(); }
-
 signals:
     /** Emitted when the last view is removed from the view manager */
     void empty();
@@ -218,6 +206,7 @@ signals:
      * activated.
      */
     void setMenuBarVisibleRequest(bool);
+    void setSaveGeometryOnExitRequest(bool);
     void updateWindowIcon();
 
     /** Requests creation of a new view with the default profile. */
@@ -227,60 +216,55 @@ signals:
 
 public slots:
     /** DBus slot that returns the number of sessions in the current view. */
-    Q_SCRIPTABLE int sessionCount();
+    int sessionCount();
 
     /** DBus slot that returns the current (active) session window */
-    Q_SCRIPTABLE int currentSession();
+    int currentSession();
 
     /** DBus slot that creates a new session in the current view.
      * @param profile the name of the profile to be used
      * @param directory the working directory where the session is
      * started.
      */
-    Q_SCRIPTABLE int newSession(QString profile, QString directory);
+    int newSession(QString profile, QString directory);
 
-    // TODO: its semantic is application-wide. Move it to more appropriate place
-    // DBus slot that returns the name of default profile
-    Q_SCRIPTABLE QString defaultProfile();
-
-    // TODO: its semantic is application-wide. Move it to more appropriate place
     // DBus slot that returns a string list of defined (known) profiles
-    Q_SCRIPTABLE QStringList profileList();
+    QStringList profileList();
 
     /** DBus slot that creates a new session in the current view with the associated
       * default profile and the default working directory
       */
-    Q_SCRIPTABLE int newSession();
+    int newSession();
 
     /** DBus slot that changes the view port to the next session */
-    Q_SCRIPTABLE void nextSession();
+    void nextSession();
 
     /** DBus slot that changes the view port to the previous session */
-    Q_SCRIPTABLE void prevSession();
+    void prevSession();
 
     /** DBus slot that switches the current session (as returned by
       * currentSession()) with the left (or previous) one in the
       * navigation tab.
       */
-    Q_SCRIPTABLE void moveSessionLeft();
+    void moveSessionLeft();
 
     /** DBus slot that Switches the current session (as returned by
       * currentSession()) with the right (or next) one in the navigation
       * tab.
       */
-    Q_SCRIPTABLE void moveSessionRight();
+    void moveSessionRight();
 
     /** DBus slot that sets ALL tabs' width to match their text */
-    Q_SCRIPTABLE void setTabWidthToText(bool);
+    void setTabWidthToText(bool);
 
 private slots:
     // called when the "Split View Left/Right" menu item is selected
     void splitLeftRight();
     void splitTopBottom();
-    void closeActiveContainer();
-    void closeOtherContainers();
-    void expandActiveContainer();
-    void shrinkActiveContainer();
+    void closeActiveView();
+    void closeOtherViews();
+    void expandActiveView();
+    void shrinkActiveView();
 
     // called when the "Detach View" menu item is selected
     void detachActiveView();
@@ -289,8 +273,8 @@ private slots:
     // called when a session terminates - the view manager will delete any
     // views associated with the session
     void sessionFinished();
-    // called when one view has been destroyed
-    void viewDestroyed(QWidget* widget);
+    // called when the container requests to close a particular view
+    void viewCloseRequest(QWidget* widget);
 
     // controller detects when an associated view is given the focus
     // and emits a signal.  ViewManager listens for that signal
@@ -299,7 +283,7 @@ private slots:
 
     // called when the active view in a ViewContainer changes, so
     // that we can plug the appropriate actions into the UI
-    void viewActivated(QWidget* view);
+    void viewActivated( QWidget* view );
 
     // called when "Next View" shortcut is activated
     void nextView();
@@ -335,7 +319,7 @@ private slots:
 
     // called when a ViewContainer requests a view be
     // moved
-    void containerMoveViewRequest(int index, int id, bool& success, TabbedViewContainer* sourceTabbedContainer);
+    void containerMoveViewRequest(int index, int id, bool& success);
 
     void detachView(ViewContainer* container, QWidget* view);
 
@@ -343,18 +327,22 @@ private slots:
 
 private:
     void createView(Session* session, ViewContainer* container, int index);
-    static const ColorScheme* colorSchemeForProfile(const Profile::Ptr profile);
+    const ColorScheme* colorSchemeForProfile(const Profile::Ptr profile) const;
 
     void setupActions();
     void focusActiveView();
+    void registerView(TerminalDisplay* view);
+    void unregisterView(TerminalDisplay* view);
 
     // takes a view from a view container owned by a different manager and places it in
     // newContainer owned by this manager
-    void takeView(ViewManager* otherManager , ViewContainer* otherContainer, ViewContainer* newContainer, TerminalDisplay* view);
+    void takeView(ViewManager* otherManager , ViewContainer* otherContainer, ViewContainer* newContainer, TerminalDisplay* view); 
     void splitView(Qt::Orientation orientation);
 
     // creates a new container which can hold terminal displays
-    ViewContainer* createContainer();
+    // 'profile' specifies the profile to use to get initial
+    // settings (eg. navigation position) for the container
+    ViewContainer* createContainer(const Profile::Ptr profile);
     // removes a container and emits appropriate signals
     void removeContainer(ViewContainer* container);
 
@@ -368,26 +356,21 @@ private:
     // about the session ( such as title and associated icon ) to the display.
     SessionController* createController(Session* session , TerminalDisplay* display);
 
+    // create menu for 'new tab' button
+    QMenu* createNewViewMenu();
 private:
     QPointer<ViewSplitter>          _viewSplitter;
     QPointer<SessionController>     _pluggedController;
 
-    QHash<TerminalDisplay*, Session*> _sessionMap;
+    QHash<TerminalDisplay*,Session*> _sessionMap;
 
     KActionCollection*                  _actionCollection;
     QSignalMapper*                      _containerSignalMapper;
+    NavigationMethod                _navigationMethod;
 
-    NavigationMethod  _navigationMethod;
-
-    ViewContainer::NavigationVisibility _navigationVisibility;
-    ViewContainer::NavigationPosition _navigationPosition;
-    bool _showQuickButtons;
-    NewTabBehavior _newTabBehavior;
-    QString _navigationStyleSheet;
-
-    int _managerId;
-    static int lastManagerId;
+    QMenu* _newViewMenu;
 };
+
 }
 
 #endif
